cmd

package
v0.0.0-...-44b3040 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2021 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

const (
	QUESTION_TEMPLATE = `` /* 661-byte string literal not displayed */

)

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

type Config

type Config struct {
	Question QuestionConfig
}

type MetaInfo

type MetaInfo struct {
	Hash     string
	UserName string
	InitDate string
	Subject  string
}

type Options

type Options struct {
	Name    string
	Content string
}

type Question

type Question struct {
	Greet     string
	UserInput UserInput
	Result    string
	MetaInfo  MetaInfo
}

Question struct

func NewQuestion

func NewQuestion(userInput UserInput, name string) (*Question, error)

NewQuestion returns pointer of Question struct that made by options

func (*Question) Execute

func (question *Question) Execute() (err error)

func (*Question) Save

func (question *Question) Save() (err error)

生成された質問を保存する

type QuestionConfig

type QuestionConfig struct {
	Name string
}

type RequireUserInput

type RequireUserInput struct {
	Subject     string
	Ideal       string
	Problem     string
	Procedure   string
	TriedAction string
}

type UserInput

type UserInput struct {
	RequireUserInput RequireUserInput
	Source           string
	Reference        string
	Log              string
	Env              string
}

Jump to